pub struct DMSCGrpcConfig {
pub addr: String,
pub port: u16,
pub max_concurrent_requests: u32,
pub enable_tls: bool,
pub cert_path: Option<String>,
pub key_path: Option<String>,
}Fields
addr: Stringport: u16max_concurrent_requests: u32enable_tls: boolcert_path: Option<String>key_path: Option<String>Trait Implementations
Sourceimpl Clone for DMSCGrpcConfig
impl Clone for DMSCGrpcConfig
Sourcefn clone(&self) -> DMSCGrpcConfig
fn clone(&self) -> DMSCGrpcConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DMSCGrpcConfig
impl Debug for DMSCGrpcConfig
Sourceimpl Default for DMSCGrpcConfig
impl Default for DMSCGrpcConfig
Sourceimpl<'py> IntoPyObject<'py> for DMSCGrpcConfig
impl<'py> IntoPyObject<'py> for DMSCGrpcConfig
Sourcetype Target = DMSCGrpcConfig
type Target = DMSCGrpcConfig
The Python output type
Sourcetype Output = Bound<'py, <DMSCGrpcConfig as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DMSCGrpcConfig as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for DMSCGrpcConfig
impl PartialEq for DMSCGrpcConfig
Sourceimpl PyClass for DMSCGrpcConfig
impl PyClass for DMSCGrpcConfig
Sourceimpl PyClassImpl for DMSCGrpcConfig
impl PyClassImpl for DMSCGrpcConfig
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DMSCGrpcConfig>
type ThreadChecker = SendablePyClass<DMSCGrpcConfig>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for DMSCGrpcConfig
impl PyClassNewTextSignature for DMSCGrpcConfig
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<DMSCGrpcConfig> for PyClassImplCollector<DMSCGrpcConfig>
impl PyMethods<DMSCGrpcConfig> for PyClassImplCollector<DMSCGrpcConfig>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for DMSCGrpcConfig
impl PyTypeInfo for DMSCGrpcConfig
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for DMSCGrpcConfig
impl Eq for DMSCGrpcConfig
impl ExtractPyClassWithClone for DMSCGrpcConfig
impl StructuralPartialEq for DMSCGrpcConfig