pub struct DMSCGrpcServiceRegistryPy { /* private fields */ }Trait Implementations
Sourceimpl Default for DMSCGrpcServiceRegistryPy
Available on crate features grpc and pyo3 only.
impl Default for DMSCGrpcServiceRegistryPy
Available on crate features
grpc and pyo3 only.Sourceimpl<'py> IntoPyObject<'py> for DMSCGrpcServiceRegistryPy
impl<'py> IntoPyObject<'py> for DMSCGrpcServiceRegistryPy
Sourcetype Target = DMSCGrpcServiceRegistryPy
type Target = DMSCGrpcServiceRegistryPy
The Python output type
Sourcetype Output = Bound<'py, <DMSCGrpcServiceRegistryPy as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DMSCGrpcServiceRegistryPy as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for DMSCGrpcServiceRegistryPy
impl PyClass for DMSCGrpcServiceRegistryPy
Sourceimpl PyClassImpl for DMSCGrpcServiceRegistryPy
impl PyClassImpl for DMSCGrpcServiceRegistryPy
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DMSCGrpcServiceRegistryPy>
type ThreadChecker = SendablePyClass<DMSCGrpcServiceRegistryPy>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for DMSCGrpcServiceRegistryPy
impl PyClassNewTextSignature for DMSCGrpcServiceRegistryPy
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<DMSCGrpcServiceRegistryPy> for PyClassImplCollector<DMSCGrpcServiceRegistryPy>
impl PyMethods<DMSCGrpcServiceRegistryPy> for PyClassImplCollector<DMSCGrpcServiceRegistryPy>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for DMSCGrpcServiceRegistryPy
impl PyTypeInfo for DMSCGrpcServiceRegistryPy
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for DMSCGrpcServiceRegistryPy
impl ExtractPyClassWithClone for DMSCGrpcServiceRegistryPy